
# yjira

A brief description of what this project does and who it's for


## Installation

Install my-project with npm

```bash
  npm install my-project
  cd my-project
```
    
## Usage/Examples

```javascript
import Component from 'my-project'

function App() {
  return <Component />
}
```


## Running Tests

To run tests, run the following command

```bash
  npm run test
```


## Authors

- [@katherinepeterson](https://www.github.com/octokatherine)

